A Fast And Egile Experiment Manager


Most of the experiments conducted at lab are 
	mainly scaning particular variables.
However when there are too many things to operate,
	it will be inconvinient to do it without a managing tool.
Take Labber for example. It is an exellent tool to do experiemnts.
However Labber follows convetional software designing principles,
	and it is comercial software.
The Labber system runs very bloated and it is un-operatable un-modifiable.
It heavily relay on GUI and tidious to operate. 
So the managing tool Labber is only suitable to run few small scale experiments
that is conventional and easy.

And for those who decide to directly use python to run experiments.
It might be the better choice for freedom and modifiability compared
to Labber.
However once the system gets complicated. It will also be tideous for
	the user to manage it. 
For example in the main loop of an experiemnt.
	If some variables are scanned as shown as
